# Contributing to Baggianalysis

## Documentation styleguide

* Always write the documentation for the Python bindings
* Docstrings of overloaded constructors need to be unindented or they won't be formatted correctly by sphinx (see `exporters/Cogli1Exporter.cpp` for an example)
